==> blesta-5.10.2.zip: blesta/language/de_de/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Kunde hat meinen Benutzernamen vergessen';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Kunde Mein Passwort zurücksetzen';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Admin Mein Passwort zurücksetzen';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Kunden-Login';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Admin-Anmeldung';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'reCaptcha Freigegebener Schlüssel';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'reCaptcha-Website-Schlüssel';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Internes Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Keine';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Aktivierte Formulare';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Captcha-Anbieter';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Menschliche Verifizierung';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Paket-Suche';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Dienst Suche';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Transaktionssuche';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Suche nach Angeboten';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Suche nach Rechnungen';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Suche nach Kunden';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Intelligente Suche';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Bieten Sie Ihren Kunden die Möglichkeit, sich für oder gegen das E-Mail-Marketing zu entscheiden.';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Marketing';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Kontaktart bearbeiten';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Sprache verwenden Definition';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Name';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Kontaktart bearbeiten';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Kontaktart bearbeiten';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Kontaktart erstellen';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Sprache verwenden Definition';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Name';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Kontaktart erstellen';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Kontakttyp erstellen';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Aktivieren Sie dieses Kontrollkästchen nur, wenn Sie eine Sprachdefinition für diese Kontaktart in der benutzerdefinierten Sprachdatei hinzugefügt haben.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Es gibt keine Kontaktarten.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Wenn Sie diese Kontaktart löschen, werden alle Kontakte, die dieser Art zugewiesen sind, in die Standardart "Rechnungsstellung" eingeordnet. Sind Sie sicher, dass Sie diese Kontaktart löschen möchten?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Löschen';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'bearbeiten';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Nein';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Ja';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Optionen';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Verwendet Sprache Definition';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Name';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Kontaktarten';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Kontaktart erstellen';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Kontaktarten';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Passphrase aktualisieren';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Ich habe diese Passphrase an einem sicheren Ort gespeichert';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Passphrase des privaten Schlüssels bestätigen';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Neue Passphrase für den privaten Schlüssel';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Aktuelle Passphrase des privaten Schlüssels';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Verschlüsselung';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'WARNUNG: Es wurde eine Passphrase festgelegt. Sie müssen Zahlungen manuell mit Ihrer Passphrase stapeln. Wenn Sie Ihre Passphrase in eine leere Passphrase ändern, wird diese Anforderung aufgehoben.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'WARNUNG: Das Festlegen einer Passphrase verhindert, dass lokal gespeicherte Zahlungskonten automatisch verarbeitet werden. Sie müssen Zahlungen manuell stapeln, indem Sie Ihre Passphrase eingeben. Weitere Informationen zu dieser Funktion entnehmen Sie bitte dem Handbuch.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Verschlüsselung';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Sind Sie sicher, dass Sie die Sprache %1$s deinstallieren möchten? Diese Sprache wird deinstalliert und alle E-Mail-Vorlagen in dieser Sprache werden dauerhaft gelöscht.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Sind Sie sicher, dass Sie die Sprache %1$s installieren wollen?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Deinstallieren Sie';
$lang['AdminCompanyGeneral.international.option_install'] = 'Installieren Sie';
$lang['AdminCompanyGeneral.international.text_options'] = 'Optionen';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Sprache';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Internationalisierung';
$lang['AdminCompanyGeneral.international.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Internationalisierung';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Unter translate.blesta.com gibt es ein Crowdsourced Translation Project. Sie können dort zu Sprachübersetzungen beitragen und diese herunterladen. Zur Installation entpacken Sie den Inhalt der Datei in Ihr Blesta-Installationsverzeichnis. Aktualisieren Sie dann diese Seite, und klicken Sie auf den Link Installieren.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Standard Land';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Datum Zeitformat';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Datum Format';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Zeitzone';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Montag';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Sonntag';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Kalender Starttag';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Der Kunde kann die Sprache einstellen';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Standardsprache';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Lokalisierung';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Lokalisierung';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Dies ist das standardmäßig verwendete Captcha, für das interne Captcha ist die GD-Erweiterung erforderlich.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Dies ist das Land, das in den entsprechenden Formularen standardmäßig ausgewählt wird.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Legt das Format für Datum und Uhrzeit fest. Dieses Format wird bei der Anzeige von Datum und Uhrzeit verwendet. Die verfügbaren Optionen entnehmen Sie bitte dem php-Handbuch.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Legt das Datumsformat fest. Dieses Format wird verwendet, wenn ein Datum angezeigt wird. Die verfügbaren Optionen entnehmen Sie bitte dem php-Handbuch.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Dies ist die Systemzeitzone, in die Datums- und Zeitumrechnungen formatiert werden.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Legen Sie den wöchentlichen Starttag des Kalenders fest.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Wenn diese Option aktiviert ist, können die Kunden ihre eigene Sprache aus den im System verfügbaren Sprachen auswählen.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Die vom System verwendete Standardsprache. Um weitere Sprachen hinzuzufügen, siehe Internationalisierungseinstellungen.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Die Einstellungen für die menschliche Überprüfung wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Die Einstellungen für die intelligente Suche wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Die Marketing-Einstellungen wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Die Sprache %1$s wurde erfolgreich deinstalliert.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'Die Sprache %1$s wurde erfolgreich installiert.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Der Kontakttyp "%1$s" wurde erfolgreich gelöscht.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Die Kontaktart "%1$s" wurde erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Der Kontakttyp "%1$s" wurde erfolgreich hinzugefügt.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Die Verschlüsselungseinstellungen wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Die Lokalisierungseinstellungen wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'Die GD-Erweiterung ist erforderlich, um das interne Captcha zu erzeugen.';

==> blesta-5.11.4.zip: blesta/language/de_de/admin_company_general.php <==
<?php
/**
 * Admin Company General
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminCompanyGeneral.humanverification.field_submit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_forgot'] = 'Kunde hat meinen Benutzernamen vergessen';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login_reset'] = 'Kunde Mein Passwort zurücksetzen';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login_reset'] = 'Admin Mein Passwort zurücksetzen';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_client_login'] = 'Kunden-Login';
$lang['AdminCompanyGeneral.humanverification.field_captcha_enabled_forms_admin_login'] = 'Admin-Anmeldung';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_shared_key'] = 'reCaptcha Freigegebener Schlüssel';
$lang['AdminCompanyGeneral.humanverification.field_recaptcha_pub_key'] = 'reCaptcha-Website-Schlüssel';
$lang['AdminCompanyGeneral.humanverification.field_captcha_internalcaptcha'] = 'Internes Captcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_recaptcha'] = 'reCaptcha';
$lang['AdminCompanyGeneral.humanverification.field_captcha_none'] = 'Keine';
$lang['AdminCompanyGeneral.humanverification.field_captcha'] = 'Captcha';
$lang['AdminCompanyGeneral.humanverification.heading_enabled_forms'] = 'Aktivierte Formulare';
$lang['AdminCompanyGeneral.humanverification.heading_captcha_provider'] = 'Captcha-Anbieter';
$lang['AdminCompanyGeneral.humanverification.boxtitle_humanverification'] = 'Menschliche Verifizierung';
$lang['AdminCompanyGeneral.smartsearch.field_submit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.smartsearch.field_package_search'] = 'Paket-Suche';
$lang['AdminCompanyGeneral.smartsearch.field_service_search'] = 'Dienst Suche';
$lang['AdminCompanyGeneral.smartsearch.field_transaction_search'] = 'Transaktionssuche';
$lang['AdminCompanyGeneral.smartsearch.field_quotation_search'] = 'Suche nach Angeboten';
$lang['AdminCompanyGeneral.smartsearch.field_invoice_search'] = 'Suche nach Rechnungen';
$lang['AdminCompanyGeneral.smartsearch.field_client_search'] = 'Suche nach Kunden';
$lang['AdminCompanyGeneral.smartsearch.boxtitle_smartsearch'] = 'Intelligente Suche';
$lang['AdminCompanyGeneral.marketing.field_submit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.marketing.field_show_receive_email_marketing'] = 'Bieten Sie Ihren Kunden die Möglichkeit, sich für oder gegen das E-Mail-Marketing zu entscheiden.';
$lang['AdminCompanyGeneral.marketing.boxtitle_marketing'] = 'Marketing';
$lang['AdminCompanyGeneral.editcontacttype.field_contacttypesubmit'] = 'Kontaktart bearbeiten';
$lang['AdminCompanyGeneral.editcontacttype.field_is_lang'] = 'Sprache verwenden Definition';
$lang['AdminCompanyGeneral.editcontacttype.field_name'] = 'Name';
$lang['AdminCompanyGeneral.editcontacttype.boxtitle_editcontacttype'] = 'Kontaktart bearbeiten';
$lang['AdminCompanyGeneral.editcontacttype.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Kontaktart bearbeiten';
$lang['AdminCompanyGeneral.addcontacttype.field_contacttypesubmit'] = 'Kontaktart erstellen';
$lang['AdminCompanyGeneral.addcontacttype.field_is_lang'] = 'Sprache verwenden Definition';
$lang['AdminCompanyGeneral.addcontacttype.field_name'] = 'Name';
$lang['AdminCompanyGeneral.addcontacttype.boxtitle_addcontacttype'] = 'Kontaktart erstellen';
$lang['AdminCompanyGeneral.addcontacttype.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Kontakttyp erstellen';
$lang['AdminCompanyGeneral.!contacttypes.is_lang'] = 'Aktivieren Sie dieses Kontrollkästchen nur, wenn Sie eine Sprachdefinition für diese Kontaktart in der benutzerdefinierten Sprachdatei hinzugefügt haben.';
$lang['AdminCompanyGeneral.contacttypes.no_results'] = 'Es gibt keine Kontaktarten.';
$lang['AdminCompanyGeneral.contacttypes.modal_delete'] = 'Wenn Sie diese Kontaktart löschen, werden alle Kontakte, die dieser Art zugewiesen sind, in die Standardart "Rechnungsstellung" eingeordnet. Sind Sie sicher, dass Sie diese Kontaktart löschen möchten?';
$lang['AdminCompanyGeneral.contacttypes.option_delete'] = 'Löschen';
$lang['AdminCompanyGeneral.contacttypes.option_edit'] = 'bearbeiten';
$lang['AdminCompanyGeneral.contacttypes.text_no'] = 'Nein';
$lang['AdminCompanyGeneral.contacttypes.text_yes'] = 'Ja';
$lang['AdminCompanyGeneral.contacttypes.heading_options'] = 'Optionen';
$lang['AdminCompanyGeneral.contacttypes.heading_define'] = 'Verwendet Sprache Definition';
$lang['AdminCompanyGeneral.contacttypes.heading_name'] = 'Name';
$lang['AdminCompanyGeneral.contacttypes.boxtitle_types'] = 'Kontaktarten';
$lang['AdminCompanyGeneral.contacttypes.categorylink_addtype'] = 'Kontaktart erstellen';
$lang['AdminCompanyGeneral.contacttypes.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Kontaktarten';
$lang['AdminCompanyGeneral.encryption.field_encryptionsubmit'] = 'Passphrase aktualisieren';
$lang['AdminCompanyGeneral.encryption.field_agree'] = 'Ich habe diese Passphrase an einem sicheren Ort gespeichert';
$lang['AdminCompanyGeneral.encryption.field_confirm_new_passphrase'] = 'Passphrase des privaten Schlüssels bestätigen';
$lang['AdminCompanyGeneral.encryption.field_private_key_passphrase'] = 'Neue Passphrase für den privaten Schlüssel';
$lang['AdminCompanyGeneral.encryption.field_current_passphrase'] = 'Aktuelle Passphrase des privaten Schlüssels';
$lang['AdminCompanyGeneral.encryption.boxtitle_encryption'] = 'Verschlüsselung';
$lang['AdminCompanyGeneral.!notice.passphrase_set'] = 'WARNUNG: Es wurde eine Passphrase festgelegt. Sie müssen Zahlungen manuell mit Ihrer Passphrase stapeln. Wenn Sie Ihre Passphrase in eine leere Passphrase ändern, wird diese Anforderung aufgehoben.';
$lang['AdminCompanyGeneral.!notice.passphrase'] = 'WARNUNG: Das Festlegen einer Passphrase verhindert, dass lokal gespeicherte Zahlungskonten automatisch verarbeitet werden. Sie müssen Zahlungen manuell stapeln, indem Sie Ihre Passphrase eingeben. Weitere Informationen zu dieser Funktion entnehmen Sie bitte dem Handbuch.';
$lang['AdminCompanyGeneral.encryption.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Verschlüsselung';
$lang['AdminCompanyGeneral.international.confirm_uninstall'] = 'Sind Sie sicher, dass Sie die Sprache %1$s deinstallieren möchten? Diese Sprache wird deinstalliert und alle E-Mail-Vorlagen in dieser Sprache werden dauerhaft gelöscht.';
$lang['AdminCompanyGeneral.international.confirm_install'] = 'Sind Sie sicher, dass Sie die Sprache %1$s installieren wollen?';
$lang['AdminCompanyGeneral.international.option_uninstall'] = 'Deinstallieren Sie';
$lang['AdminCompanyGeneral.international.option_install'] = 'Installieren Sie';
$lang['AdminCompanyGeneral.international.text_options'] = 'Optionen';
$lang['AdminCompanyGeneral.international.text_iso'] = 'ISO 639-1, 3166-1';
$lang['AdminCompanyGeneral.international.text_language'] = 'Sprache';
$lang['AdminCompanyGeneral.international.boxtitle_international'] = 'Internationalisierung';
$lang['AdminCompanyGeneral.international.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Internationalisierung';
$lang['AdminCompanyGeneral.!notice.international_languages'] = 'Unter translate.blesta.com gibt es ein Crowdsourced Translation Project. Sie können dort zu Sprachübersetzungen beitragen und diese herunterladen. Zur Installation entpacken Sie den Inhalt der Datei in Ihr Blesta-Installationsverzeichnis. Aktualisieren Sie dann diese Seite, und klicken Sie auf den Link Installieren.';
$lang['AdminCompanyGeneral.localization.field.localizationsubmit'] = 'Einstellungen aktualisieren';
$lang['AdminCompanyGeneral.localization.field.country'] = 'Standard Land';
$lang['AdminCompanyGeneral.localization.field.datetimeformat'] = 'Datum Zeitformat';
$lang['AdminCompanyGeneral.localization.field.dateformat'] = 'Datum Format';
$lang['AdminCompanyGeneral.localization.field.timezone'] = 'Zeitzone';
$lang['AdminCompanyGeneral.localization.field.monday'] = 'Montag';
$lang['AdminCompanyGeneral.localization.field.sunday'] = 'Sonntag';
$lang['AdminCompanyGeneral.localization.field.calendar'] = 'Kalender Starttag';
$lang['AdminCompanyGeneral.localization.field.setlanguage'] = 'Der Kunde kann die Sprache einstellen';
$lang['AdminCompanyGeneral.localization.field.language'] = 'Standardsprache';
$lang['AdminCompanyGeneral.localization.tz_format'] = '(UTC %1$s) %2$s';
$lang['AdminCompanyGeneral.localization.boxtitle_localization'] = 'Lokalisierung';
$lang['AdminCompanyGeneral.localization.page_title'] = 'Einstellungen > Unternehmen > Allgemein > Lokalisierung';
$lang['AdminCompanyGeneral.!tooltip.captcha'] = 'Dies ist das standardmäßig verwendete Captcha, für das interne Captcha ist die GD-Erweiterung erforderlich.';
$lang['AdminCompanyGeneral.!tooltip.country'] = 'Dies ist das Land, das in den entsprechenden Formularen standardmäßig ausgewählt wird.';
$lang['AdminCompanyGeneral.!tooltip.datetime_format'] = 'Legt das Format für Datum und Uhrzeit fest. Dieses Format wird bei der Anzeige von Datum und Uhrzeit verwendet. Die verfügbaren Optionen entnehmen Sie bitte dem php-Handbuch.';
$lang['AdminCompanyGeneral.!tooltip.date_format'] = 'Legt das Datumsformat fest. Dieses Format wird verwendet, wenn ein Datum angezeigt wird. Die verfügbaren Optionen entnehmen Sie bitte dem php-Handbuch.';
$lang['AdminCompanyGeneral.!tooltip.timezone'] = 'Dies ist die Systemzeitzone, in die Datums- und Zeitumrechnungen formatiert werden.';
$lang['AdminCompanyGeneral.!tooltip.calendar_begins'] = 'Legen Sie den wöchentlichen Starttag des Kalenders fest.';
$lang['AdminCompanyGeneral.!tooltip.client_set_lang'] = 'Wenn diese Option aktiviert ist, können die Kunden ihre eigene Sprache aus den im System verfügbaren Sprachen auswählen.';
$lang['AdminCompanyGeneral.!tooltip.language'] = 'Die vom System verwendete Standardsprache. Um weitere Sprachen hinzuzufügen, siehe Internationalisierungseinstellungen.';
$lang['AdminCompanyGeneral.!success.humanverification_updated'] = 'Die Einstellungen für die menschliche Überprüfung wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.smartsearch_updated'] = 'Die Einstellungen für die intelligente Suche wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.marketing_updated'] = 'Die Marketing-Einstellungen wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.language_uninstalled'] = 'Die Sprache %1$s wurde erfolgreich deinstalliert.';
$lang['AdminCompanyGeneral.!success.language_installed'] = 'Die Sprache %1$s wurde erfolgreich installiert. Denken Sie daran, E-Mails, Pakete und Paketgruppen mit dem Inhalt für die neue Sprache zu aktualisieren.';
$lang['AdminCompanyGeneral.!success.contact_type_deleted'] = 'Der Kontakttyp "%1$s" wurde erfolgreich gelöscht.';
$lang['AdminCompanyGeneral.!success.contact_type_updated'] = 'Die Kontaktart "%1$s" wurde erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.contact_type_added'] = 'Der Kontakttyp "%1$s" wurde erfolgreich hinzugefügt.';
$lang['AdminCompanyGeneral.!success.encryption_updated'] = 'Die Verschlüsselungseinstellungen wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!success.localization_updated'] = 'Die Lokalisierungseinstellungen wurden erfolgreich aktualisiert.';
$lang['AdminCompanyGeneral.!error.captcha_gd'] = 'Die GD-Erweiterung ist erforderlich, um das interne Captcha zu erzeugen.';
